=======
History
=======

0.1.6 (2020-04-11)
------------------

* Add Reporcessing. Revise Functional units. Reivse parameters class.


0.1.0 (2020-02-27)
------------------

* First release on PyPI. Main functionality: LCA, Monte-Carlo, and Optimization. Process Models include LF, WTE, Composting, AD, SS_MRF nd Collection.
